:orphan:

********
See Also
********

.. table::

   +-------------+---------------------------------------------+
   | Document    | Description                                 |
   +=============+=============================================+
   | `glossary`_ | Python glossary (files, classes, methods).  |
   +-------------+---------------------------------------------+
   | `logging`_  | Package logging configuration and examples. |
   +-------------+---------------------------------------------+

.. _glossary: glossary.html
.. _logging: logging.html

.. only:: not html

   - Glossary — Python glossary (files, classes, methods).
   - Logging — Package logging configuration and examples.
   - API — Auto-generated API reference from docstrings.


*******
License
*******

GPL-3.0-only WITH Classpath-Exception-2.0 OR BSD-3-Clause

Copyright 2025 Bernd Stroehle
